from panda3d.core import CardMaker, Texture, loadPrcFileData, Shader, PNMImage
from MyFilterManager import FilterManager

from math import sqrt

def generate(size=64, factor=1.0/256, max_value=1.0):
    half_size = size / 2
    p = PNMImage(size, size, num_channels=2, maxval=65535)
    for y in xrange(size):
        ry = (y - half_size + 0.5) / size
        for x in xrange(size):
            rx = (x - half_size + 0.5) / size
            dist = sqrt(rx*rx + ry*ry)
            value = min(1.0, pow(factor, sqrt(dist)))
            v = value * max_value
            p.set_xel_a(x, y, v, v, v, v)
    texture = Texture()
    texture.load(p)
    return texture

srgb_tex = True
srgb_main = True
buffer = True
srgb_buffer = True
srgb_shader = False
multisamples_main = 0
multisamples_buffer = 2
floatcolor = False

gen = True

if srgb_main:
    loadPrcFileData("", "framebuffer-srgb true\n")
if buffer:
    loadPrcFileData("", "textures-power-2 none\n")

loadPrcFileData("", "gl-version 3 2\n")

if multisamples_main > 0:
    loadPrcFileData("", "framebuffer-multisample 1\n"
                        "multisamples %d\n" % multisamples_main)

import direct.directbase.DirectStart

cm = CardMaker('card')
card = render.attachNewNode(cm.generate())
card.set_pos(-0.5, 2, -0.5)
if gen:
    tex=generate()
else:
    tex = loader.loadTexture('maps/circle.png')
    if srgb_tex:
        tex.set_format(Texture.F_srgb_alpha)
card.setTexture(tex)
shader = Shader.load(Shader.SL_GLSL,
                    vertex='card.vertex.glsl',
                    fragment='card.fragment.glsl')
card.setShader(shader)

if buffer:
    manager = FilterManager(base.win, base.cam)
    color_buffer = Texture()
    final_quad = manager.renderSceneInto(colortex=color_buffer, srgb=srgb_buffer, floatcolor=floatcolor, multisamples=multisamples_buffer)
    if srgb_shader:
        shader = Shader.load(Shader.SL_GLSL, vertex='postprocess.vertex.glsl', fragment='postprocess.srgb.fragment.glsl')
    else:
        shader = Shader.load(Shader.SL_GLSL, vertex='postprocess.vertex.glsl', fragment='postprocess.fragment.glsl')
    final_quad.setShader(shader)
    final_quad.setShaderInput("color_buffer", color_buffer)

base.run()
